import { createRouter, createWebHistory, RouteRecordRaw } from 'vue-router'

const routes: RouteRecordRaw[] = [
  { path: '/', redirect: '/shows' },
  {
    path: '/shows',
    children: [
      {
        path: '',
        name: 'shows',
        component: () => import('@/Pages/MyShows.vue'),
      },
      {
        path: ':showId',
        name: 'show',
        component: () => import('@/Pages/Show.vue'),
        redirect: (to) => ({
          name: 'show-timeslots',
          params: { showId: to.params.showId },
        }),
        children: [
          {
            path: 'basic-data',
            name: 'show-basic-data',
            component: () => import('@/Pages/ShowBasicData.vue'),
          },
          {
            path: 'episodes',
            children: [
              {
                path: '',
                name: 'show-episodes',
                component: () => import('@/Pages/ShowEpisodes.vue'),
              },
              {
                path: ':episodeId',
                name: 'show-episode',
                component: () => import('@/Pages/ShowEpisode.vue'),
                redirect: (to) => ({
                  name: 'show-episode-details',
                  params: to.params,
                }),
                children: [
                  {
                    path: '',
                    name: 'show-episode-details',
                    component: () => import('@/Pages/ShowEpisodeDetails.vue'),
                  },
                ],
              },
            ],
          },
          {
            path: 'schedules',
            name: 'show-schedules',
            component: () => import('@/Pages/ShowSchedules.vue'),
          },
          {
            path: 'timeslots',
            children: [
              {
                path: '',
                name: 'show-timeslots',
                component: () => import('@/Pages/ShowTimeslots.vue'),
              },
              {
                path: ':timeslotId',
                name: 'show-timeslot',
                component: () => import('@/Pages/ShowTimeslot.vue'),
                redirect: (to) => ({
                  name: 'show-timeslot-details',
                  params: to.params,
                }),
                children: [
                  {
                    path: '',
                    name: 'show-timeslot-details',
                    component: () => import('@/Pages/ShowEpisodeDetails.vue'),
                  },
                ],
              },
            ],
          },
        ],
      },
    ],
  },
  {
    path: '/my',
    component: () => import('@/Pages/CurrentUser.vue'),
    children: [
      {
        path: 'account',
        name: 'my-account',
        component: () => import('@/Pages/MyAccount.vue'),
      },
    ],
  },
  {
    path: '/profiles',
    children: [
      {
        path: '/profiles',
        name: 'profiles',
        component: () => import('@/Pages/ProfileList.vue'),
      },
      {
        path: ':profileId',
        name: 'profile',
        component: () => import('@/Pages/Profile.vue'),
        redirect: (to) => ({ path: `/profiles/${to.params.profileId}/details` }),
        children: [
          {
            path: 'details',
            name: 'profile-details',
            component: () => import('@/Pages/ProfileDetails.vue'),
          },
        ],
      },
    ],
  },
  { path: '/calendar', name: 'calendar', component: () => import('@/Pages/Calendar.vue') },
  { path: '/credits', name: 'credits', component: () => import('@/Pages/Credits.vue') },
]

export default createRouter({
  history: createWebHistory(),
  routes,
})
