import {
  APICreate,
  APIListPaginated,
  APIRemove,
  APIRetrieve,
  APIUpdate,
  createExtendableAPI,
  useObjectFromStore,
} from '@rokoli/bnb/drf'
import { defineStore } from 'pinia'

import { createSteeringURL } from '@/api'
import { steeringAuthInit } from '@/stores/auth'
import { Episode, EpisodeCreateData, EpisodeUpdateData } from '@/types'
import { aggregateWithIdsParameter } from '@/util/api'
import { MaybeRefOrGetter, toValue } from 'vue'
import { useFallbackShow, useShowStore } from '@/stores/shows'
import { useMediaCascade } from '@/stores/media'

export const useEpisodeStore = defineStore('episodes', () => {
  const endpoint = createSteeringURL.prefix('episodes')
  const { api, base } = createExtendableAPI<Episode>(endpoint, steeringAuthInit)
  const listOperations = APIListPaginated(api)
  return {
    ...base,
    ...listOperations,
    ...APIRetrieve(api, {
      aggregate: aggregateWithIdsParameter(listOperations.listIsolated),
    }),
    ...APICreate<Episode, EpisodeCreateData>(api),
    ...APIUpdate<Episode, EpisodeUpdateData>(api),
    ...APIRemove(api),
  }
})

export function useEpisodeMediaCascade(episode: MaybeRefOrGetter<Episode | null>) {
  const showStore = useShowStore()

  const { obj: show } = useObjectFromStore(() => toValue(episode)?.showId ?? null, showStore)
  const { obj: fallback } = useFallbackShow()

  return useMediaCascade(
    () => ({ mediaId: toValue(episode)?.mediaId }),
    () => ({ mediaId: show.value?.defaultMediaId, inheritedFrom: 'show' as const }),
    () => ({ mediaId: fallback.value?.defaultMediaId, inheritedFrom: 'fallbackShow' as const }),
  )
}
