import { ID } from '@rokoli/bnb/drf'

import { components, components as steeringComponents } from '@/steering-types'
import { components as tankComponents } from '@/tank-types'

export type PaginationData = {
  count: number
  hasNext: boolean
  hasPrevious: boolean
  page: number
  itemsPerPage: number
  itemRange: [number, number]
}

export type KeysFrom<T, K extends keyof T> = K
export type PickOfType<T, V> = { [K in keyof T as T[K] extends V ? K : never]: T[K] }
export type AnyRelations<T extends object> = { [K in keyof T]: T[K] extends ID[] ? T[K] : never }

export type UpdatedMetadata = {
  updatedAt: string | null
  updatedBy: string
}

export type CreatedMetadata = {
  createdAt: string
  createdBy: string
}

export type EditingMetaData = UpdatedMetadata & CreatedMetadata

export type ImageFrameSpec = {
  aspectRatio?: [number, number]
  shape?: 'round' | 'rect'
}

type ReadonlyAttrs = 'id' | 'createdAt' | 'createdBy' | 'updatedAt' | 'updatedBy'

export type AnyPermission = steeringComponents['schemas']['AnyPermission']

type _Episode = steeringComponents['schemas']['Episode']
type _EpisodeReadonlyAttrs = ReadonlyAttrs | 'timeslotIds'
export type Episode = Required<_Episode>
export type EpisodeCreateData = Omit<_Episode, _EpisodeReadonlyAttrs>
export type EpisodeUpdateData = Partial<EpisodeCreateData>

export type ContentLicense = steeringComponents['schemas']['ContentLicense']

type _Image = steeringComponents['schemas']['Image']
type _ImageReadonlyAttrs = ReadonlyAttrs | 'height' | 'width' | 'image' | 'url'
export type Image = Required<_Image>
export type NewImage = Omit<Image, 'id' | 'image' | 'file'> & { file: globalThis.File | Blob }
export type ImageCreateData = Omit<Image, _ImageReadonlyAttrs> & { image: globalThis.File }
export type ImageUpdateData = Omit<Image, _ImageReadonlyAttrs>

type _MediaSource = steeringComponents['schemas']['MediaSource']
export type MediaSource = Required<_MediaSource>
export type MediaSourceCreateData =
  | Pick<MediaSource, 'mediaId' | 'duration' | 'fileId'>
  | Pick<MediaSource, 'mediaId' | 'duration' | 'uri'>
export type MediaSourceUpdateData = Partial<MediaSourceCreateData>

type _Media = steeringComponents['schemas']['Media']
export type Media = Required<Omit<_Media, 'entries'> & { entries: MediaSource[] }>
export type MediaCreateData = Omit<_Media, ReadonlyAttrs | 'entries'>
export type MediaUpdateData = Partial<MediaCreateData>

export type TimeSlot = Required<steeringComponents['schemas']['TimeSlot']>
export type Show = Required<steeringComponents['schemas']['Show']>
export type File = Required<tankComponents['schemas']['store.File']>
export type FileMetadata = Required<tankComponents['schemas']['store.FileMetadata']>
export type Import = Required<tankComponents['schemas']['importer.Job']>
export type Schedule = Required<steeringComponents['schemas']['Schedule']>
export type ScheduleCreateData = components['schemas']['ScheduleCreateUpdateRequest']
export type ScheduleConflictSolution = components['schemas']['SolutionChoicesEnum']
export type ScheduleConflictResponse = components['schemas']['ScheduleConflictResponse']
export type ScheduleCollision = components['schemas']['Collision']
export type ProjectedTimeSlot = components['schemas']['ProjectedTimeSlot']
export type Profile = Required<steeringComponents['schemas']['Profile']>
export type Category = Required<steeringComponents['schemas']['Category']>
export type FundingCategory = Required<steeringComponents['schemas']['FundingCategory']>
export type Language = Required<steeringComponents['schemas']['Language']>
export type MusicFocus = Required<steeringComponents['schemas']['MusicFocus']>
export type Type = Required<steeringComponents['schemas']['Type']>
export type Topic = Required<steeringComponents['schemas']['Topic']>
export type License = Required<steeringComponents['schemas']['License']>
export type LinkType = Required<steeringComponents['schemas']['LinkType']>
export type Link = { typeId: LinkType['id'] | null; url: string }
export type ProgramEntry = steeringComponents['schemas']['BasicProgramEntry']
export type RadioSettings = Required<steeringComponents['schemas']['RadioSettings']>
export type RRule = Required<
  Omit<steeringComponents['schemas']['RRule'], 'byWeekdays'> & {
    // this is an extension to ease testing
    byWeekdays: steeringComponents['schemas']['RRule']['byWeekdays'] | number[]
  }
>

declare module 'csstype' {
  interface Properties {
    // Add a missing property
    'anchor-name'?: string
    'position-anchor'?: string
  }
}
