import { fileURLToPath } from 'node:url'

import { APIRequestContext } from '@playwright/test'
import { createURLBuilder } from '@rokoli/bnb/common'

const steeringOrigin = createURLBuilder(process.env.STEERING_ORIGIN as string)
export const steeringAPI = steeringOrigin.prefix('api', 'v1')

const tankOrigin = createURLBuilder(process.env.TANK_ORIGIN as string, false)
export const tankAPI = tankOrigin.prefix('api', 'v1')

export function purgeSteeringState(
  request: APIRequestContext,
  options?: { params?: Record<string, string>; report?: boolean },
): Promise<Record<string, number>> {
  const result = request
    .delete(steeringAPI('debug', 'application-state'), {
      params: options?.params ?? {},
      failOnStatusCode: true,
    })
    .then((res) => res.json())
  if (options?.report) void result.then(reportDeleteCounts.bind(null, 'steering'))
  return result
}

export function purgeTankState(
  request: APIRequestContext,
  options?: { params?: Record<string, string>; report?: boolean },
): Promise<Record<string, number>> {
  const result = request
    .delete(tankAPI('debug', 'application-state'), {
      params: options?.params ?? {},
      failOnStatusCode: true,
    })
    .then((res) => res.json())
  if (options?.report) void result.then(reportDeleteCounts.bind(null, 'tank'))
  return result
}

export function reportDeleteCounts(source: string, deleteCounts: Record<string, number>): void {
  if (Object.keys(deleteCounts).length === 0) return
  const result = []
  let total = 0
  for (const [key, value] of Object.entries(deleteCounts)) {
    if (value === 0) continue
    result.push(`${key}: ${value}`)
    total += value
  }
  console.debug(`Deleted ${total} record(s) from ${source}:\n\t${result.join(', ')}`)
}

export function getFileMetadata(filename: string) {
  return {
    name: filename,
    path: fileURLToPath(new URL(`./files/${filename}`, import.meta.url)),
  }
}
